@@ -10,11 +10,11 @@ WWW::Session - WWW Sessions with multiple backends and object serialization
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -906,7 +906,7 @@ sub import {
     }
     if (defined $params{fields}) {
         foreach my $field (keys %{$params{fields}}) {
-            $class->setup_field($field,$params{fields}->{$field});
+            $class->setup_field($field,%{ $params{fields}->{$field} });
         }
     }
 }
